import bb.cascades 1.3
import bb.system 1.2

Sheet {
    id: tutorialSheet
    onOpened: {
        listView.scrollToItem([0], ScrollAnimation.Smooth)
        listView.sheetOpened = true
//        mainPage.tutorialOpened = true
        if (aboutSheet.opened)
            aboutSheet.close()
    }
    onClosed: {
        listView.sheetOpened = false
        
        _settings.setValue("delay", 1000) //Default
        _settings.setValue("batterySavingModeEnabled", false) // Default
        _settings.setValue("batterySavingModeTimerInterval", 10) // Default

        if (_settings.value("landscapeUser", true)) {
            _settings.setValue("batterySavingModeEnabled", true)
            _settings.setValue("batterySavingModeTimerInterval", 5)
        }
        else {
            _settings.setValue("batterySavingModeEnabled", false)
        }
        
        if (_settings.value("powerUser", true)) {
            _settings.setValue("batterySavingModeEnabled", true)
            _settings.setValue("delay", 2000)
            _settings.setValue("batterySavingModeTimerInterval", 5)
        }
        else {
            _settings.setValue("batterySavingModeEnabled", false)
            _settings.setValue("delay", 1000)
        }

        if (!_settings.value("keepHandsClear", true)) {
            _settings.setValue("batterySavingModeEnabled", true)
            _settings.setValue("delay", 2000)
            _settings.setValue("batterySavingModeTimerInterval", 5)
        }
        
        if (_settings.value("noScreenOff", true)) {
            _settings.setValue("batterySavingModeEnabled", false)
        }

        _app.sendToHL("BATTERY_SAVING_MODE_TIMER_INTERVAL_CHANGED")
        
        settingsSheet.updateRequired()
        settingsSheet.open()        
//        mainPage.tutorialOpened = false
        if (_settings.value("batterySavingModeEnabled", false)) {
            settingsSheet.showBatterySavingModeWarning()
        }
    }
    
    attachedObjects: [
        SystemToast { id: systemToast }
    ]
    
    Page {
        id: tutorialPage
        titleBar: TitleBar {
            id: titleBar
            title: qsTr("Tutorial") + Retranslate.onLanguageChanged
            acceptAction: ActionItem {
                title: tutorialPage.pageShown == (listView.dataModel.childCount([]) - 1) ? qsTr("Done") : qsTr("Next")
                onTriggered: {
                    //listView.dataModel.childCount([])                    
                    if (tutorialPage.pageShown == (listView.dataModel.childCount([])) - 1) {
                        if (_settings.value("showFirstTimeTutorial", true))
                            _settings.setValue("showFirstTimeTutorial", false)
                            
                        tutorialSheet.close()
                    }
                    else 
                        listView.scrollToItem([tutorialPage.pageShown + 1], ScrollAnimation.Smooth)
                }
            }
            /*
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged
                onTriggered: {
                    tutorialSheet.close()
                }
            }
            */
        }
                
        property int pageShown
        
        Container {
            id: tutorialContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            background: Color.create("#FFDCD427")
            
            attachedObjects: LayoutUpdateHandler { id: luhContainer }
            
            ListView {
                id: listView
                
                property int deviceWidth: luhContainer.layoutFrame.width
                property int deviceHeight: luhContainer.layoutFrame.height
                property int itemLeftPadding: luhContainer.layoutFrame.width * 0.05
                property int itemTopPadding: luhContainer.layoutFrame.height * 0.05
                property bool sheetOpened
                property variant background: tutorialContainer.background

                scrollRole: tutorialSheet.opened ? ScrollRole.Main : ScrollRole.None
                dataModel: XmlDataModel { source: qsTr("asset:///Tutorial/tutorialModel.xml") + Retranslate.onLanguageChanged }
                layout: StackListLayout { orientation: LayoutOrientation.LeftToRight }
                flickMode: FlickMode.SingleItem
                
                function updatePageShown(page) {
                    tutorialPage.pageShown = page
                }
                
                listItemComponents: [
                    ListItemComponent {
                        type: "item"
                        Container {
                            id: itemContainer
                            layout: DockLayout {}
                            preferredWidth: itemContainer.ListItem.view.deviceWidth
                            preferredHeight: itemContainer.ListItem.view.deviceHeight
                            attachedObjects: LayoutUpdateHandler {
                                id: luhPosition
                                onLayoutFrameChanged: {
                                    if (layoutFrame.x == 0) {
                                        if (radioGroup.visible) {
                                            if (_settings.value(ListItemData.optionName, true)) 
                                                radioGroup.setSelectedOption(yesOption)
                                            else 
                                                radioGroup.setSelectedOption(noOption)
                                        }
                                    }
                                    if (luhPosition.layoutFrame.x >= - itemContainer.preferredWidth / 2 && luhPosition.layoutFrame.x <= itemContainer.preferredWidth / 2) {
                                        itemContainer.ListItem.view.updatePageShown(ListItemData.page)
                                        if (ListItemData.image != "") fadeTransition.play()
                                    } 
                                }
                            }
                            Container {
                                layout: DockLayout {}
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                                Container {
                                    topPadding: itemContainer.ListItem.view.itemTopPadding
                                    bottomPadding: topPadding
                                    horizontalAlignment: HorizontalAlignment.Center
                                    verticalAlignment: VerticalAlignment.Top
                                    ImageView {
                                        imageSource: ListItemData.image
                                        maxHeight: itemContainer.ListItem.view.deviceHeight * 0.75
                                        maxWidth: maxWidth
                                        scalingMethod: ScalingMethod.AspectFit
                                    }
                                }
                                Container {
                                    horizontalAlignment: HorizontalAlignment.Fill
                                    verticalAlignment: (ListItemData.image != "") ? VerticalAlignment.Bottom : VerticalAlignment.Center
                                    leftPadding: itemContainer.ListItem.view.itemLeftPadding
                                    rightPadding: leftPadding
                                    opacity: (ListItemData.image != "") ? 0 : 0.9
                                    background: itemContainer.ListItem.view.background
                                    animations: [
                                        FadeTransition {
                                            id: fadeTransition
                                            fromOpacity: 0.05
                                            toOpacity: 0.9
                                            duration: 3500
//                                            easingCurve: StockCurve.CircularInOut
                                        }
                                    ]
                                    ScrollView {
                                        maxHeight: itemContainer.ListItem.view.deviceHeight
                                        horizontalAlignment: HorizontalAlignment.Center
                                        Container {
                                            Label {
                                                text: ListItemData.description
                                                multiline: true
                                                textStyle.textAlign: TextAlign.Justify
                                                textStyle.fontSize: FontSize.XLarge
                                                horizontalAlignment: HorizontalAlignment.Center
                                                textStyle.color: Color.Black
                                            }
                                            RadioGroup {
                                                id: radioGroup
                                                options: [
                                                    Option {
                                                        id: yesOption
                                                        text: qsTr("Yes") + Retranslate.onLocaleOrLanguageChanged
                                                        value: true
                                                    },
                                                    Option {
                                                        id: noOption
                                                        text: qsTr("No") + Retranslate.onLocaleOrLanguageChanged
                                                        value: false
                                                    }
                                                ]
                                                horizontalAlignment: HorizontalAlignment.Center
                                                onSelectedOptionChanged: { if (visible) _settings.setValue(ListItemData.optionName, selectedValue) }
                                                visible: (ListItemData.optionVisible == "true")
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                ]    
            }
        }
    }
}
