/*
 * Copyright (c) 2013-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.3
import bb.system 1.2
import "ActiveFrame"
import "Changelog"
import "Sheets"
import "Tutorial"

Page {
    Menu.definition: MenuDefinition {
        actions: [
            ActionItem {
                title: qsTr("About") + Retranslate.onLocaleOrLanguageChanged
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/ic_info.png"
                onTriggered: { aboutSheet.open() }
            },
            ActionItem {
                title: qsTr("Settings") + Retranslate.onLocaleOrLanguageChanged
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/ic_settings.png"
                onTriggered: { settingsSheet.open() }
            }
        ]      
    }
    
    onCreationCompleted: {
        Application.setCover(activeFrame)
        if (_settings.value("showFirstTimeTutorial", true)) 
            tutorialSheet.open()
        
//        promoToast.show()
//        systemToast.body = qsTr("Sorry for sending so many new versions, the never-ending popup bug some of you are experiencing can't be reproduce on my phone, and therefore YOU are my test units. If you find those updates too annoying, leave the beta program and come back in a few days.") + Retranslate.onLocaleOrLanguageChanged
//        systemToast.show()
    }

    attachedObjects: [
        AboutSheet { id: aboutSheet },
        ActiveFrame { id: activeFrame },
        SettingsSheet { id: settingsSheet },
        TutorialSheet { id: tutorialSheet },
        SystemToast {
            id: systemToast
            button.label: qsTr("OK") + Retranslate.onLocaleOrLanguageChanged
        }/*,
        SystemDialog {
            id: promoToast
            title: qsTr("End of beta program")
            body: qsTr("This beta is over and will not be updated anymore, please get a free copy of the app by clicking 'OK' to continue getting updates. You can delete this beta app.")
            onFinished: {
                if (buttonSelection() == confirmButton) {
                    appWorldInvoke.query.setUri("appworld://promotion/POCKETSAFEFREE")
                    appWorldInvoke.query.updateQuery()
                }
            }
        },
        Invocation{
            id: appWorldInvoke
            query {
                invokeActionId: "bb.action.OPEN"
                invokeTargetId: "sys.appworld"
            }
            onArmed: {
                trigger(query.invokeActionId)
            }
        }*/
    ]
    
    ScrollView {
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        Container {
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            leftPadding: ui.du(3)
            rightPadding: leftPadding
            Container {
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                ImageView {
                    imageSource: "asset:///images/Icon%20And%20Splashscreen/MainPageBanner.png"
                    scalingMethod: ScalingMethod.AspectFit
                }
                Divider {}
                Label {
                    text: qsTr("Since PocketSafe uses the proximity sensor to determine when to lock the screen, those who frequently play games and/or type in landscape mode should use battery saving mode. Others have 2 choices :\n1) keep battery saving mode turned off, which gives you the most protection but you will have to put up the occasional pop up when you forget and place a finger or hand in front of the sensor, or\n2) keep battery saving mode on, which will eliminate the unintentional activation of the screen lock pop up, but you will have to always remember to turn off the screen before placing the phone in your pocket, purse or holster.") + Retranslate.onLocaleOrLanguageChanged
                    multiline: true
                    textStyle.textAlign: TextAlign.Justify
                    textStyle.fontSize: FontSize.Medium
                    horizontalAlignment: HorizontalAlignment.Center
                }
                Divider {}
                Label {
                    text: "This app is supported by your donation, by clicking on the Donate button, you'll be redirected to my PayPal donation account."
                    multiline: true
                    textStyle.textAlign: TextAlign.Justify
                    textStyle.fontSize: FontSize.Medium
                    horizontalAlignment: HorizontalAlignment.Center
                }
                ImageView {
                    imageSource: "asset:///images/paypal.png"
                    scalingMethod: ScalingMethod.AspectFit
                    maxWidth: ui.du(50)
                    horizontalAlignment: HorizontalAlignment.Center
                    gestureHandlers: [
                        TapHandler {
                            onTapped: { 
                                donateInvocation.query.invokeActionId = "bb.action.OPEN"
                                donateInvocation.query.invokeTargetId = "sys.browser"
                                donateInvocation.query.uri = "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=SPVU4HNBUJBH2"
                                donateInvocation.query.updateQuery()
                            }
                        }
                    ]
                    attachedObjects: [
                        Invocation {
                            id: donateInvocation
                            onArmed: { trigger(query.invokeActionId) }
                        }
                    ]
                }
            }
            ChangelogContainer { visible: false }
        }
    }
}
